import 'dart:ui';

import 'package:meta/meta.dart';

/// Application configuration model
///
/// @author Pierre HUBERT

const defaultColor = Color(0xFF1A237E);

/// Configuration class
class Config {
  final String apiServerName;
  final String apiServerUri;
  final bool apiServerSecure;
  final String clientName;
  final Color splashBackgroundColor;

  const Config({
    @required this.apiServerName,
    @required this.apiServerUri,
    @required this.apiServerSecure,
    @required this.clientName,
    this.splashBackgroundColor = defaultColor,
  })  : assert(apiServerName != null),
        assert(apiServerUri != null),
        assert(apiServerSecure != null),
        assert(clientName != null),
        assert(splashBackgroundColor != null);

  /// Get and set static configuration
  static Config _config;

  static Config get() {
    return _config;
  }

  static void set(Config conf) {
    _config = conf;
  }
}

/// Get the current configuration of the application
Config config() {
  return Config.get();
}
